package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TdIndenture;

/**
 * 维修商Service接口
 * 
 * @author ruoyi
 * @date 2024-04-08
 */
public interface ITdIndentureService 
{
    /**
     * 查询维修商
     * 
     * @param indentureId 维修商主键
     * @return 维修商
     */
    public TdIndenture selectTdIndentureByIndentureId(String indentureId);

    /**
     * 查询维修商列表
     * 
     * @param tdIndenture 维修商
     * @return 维修商集合
     */
    public List<TdIndenture> selectTdIndentureList(TdIndenture tdIndenture);

    /**
     * 新增维修商
     * 
     * @param tdIndenture 维修商
     * @return 结果
     */
    public int insertTdIndenture(TdIndenture tdIndenture);

    /**
     * 修改维修商
     * 
     * @param tdIndenture 维修商
     * @return 结果
     */
    public int updateTdIndenture(TdIndenture tdIndenture);

    /**
     * 批量删除维修商
     * 
     * @param indentureIds 需要删除的维修商主键集合
     * @return 结果
     */
    public int deleteTdIndentureByIndentureIds(String indentureIds);

    /**
     * 删除维修商信息
     * 
     * @param indentureId 维修商主键
     * @return 结果
     */
    public int deleteTdIndentureByIndentureId(String indentureId);
}
